0.7 (2020-07-13)
----------------

- Build cross-platform pip wheels.

0.6 (2020-04-18)
----------------

- Removed `astropy-helpers` from repository.

0.5 (2019-03-01)
----------------

- Added the option to initialize a ``KeplerElements`` or ``KeplerOrbit`` object
  with a specified velocity semi-amplitude, ``K``.

0.4 (2019-02-25)
----------------

- Bugfix release.

0.3 (2019-02-25)
----------------

- Added support for long-term polynomial velocity trends.

0.2 (2018-01-21)
----------------

- Added option to specify just radial velocity to ``Barycenter`` initializer.
- Docs improvements.

0.1 (2018-01-15)
----------------

- Initial release.
